View Source ConnGRPC.ConnectionError exception (ConnGRPC v0.4.3)

Raised by ConnGRPC.Pool.get_channel!/1 when a channel cannot be retrieved from the pool.

Link to this section Summary

Types

t()

Connection error exception.

Link to this section Types

@type t() :: %ConnGRPC.ConnectionError{
  __exception__: true,
  pool_name: module(),
  reason: atom()
}

Connection error exception.

fields

Fields

  • :reason - The underlying error reason (e.g. :not_connected)
  • :pool_name - The name of the pool that failed to provide a channel